@@ -32,6 +32,7 @@
 #include "qtquickitems/edgeitem.h"
 #include "dialogs/nodeproperties.h"
 #include "dialogs/edgeproperties.h"
+#include "logging_p.h"
 
 #include <KDeclarative/KDeclarative>
 
@@ -42,7 +43,6 @@
 #include <QQuickWidget>
 #include <QPointer>
 #include <QStandardPaths>
-#include <QDebug>
 
 using namespace GraphTheory;
 
@@ -78,6 +78,9 @@ View::View(QWidget *parent)
 {
     setResizeMode(QQuickWidget::SizeRootObjectToView);
 
+    // workaround for QTBUG-40765
+    qApp->setAttribute(Qt::AA_DontCreateNativeWidgetSiblings);
+
     // prepare QML engine to be globally used
     KDeclarative::KDeclarative kdeclarative;
     kdeclarative.setTranslationDomain("libgraphtheory");
@@ -102,7 +105,7 @@ View::View(QWidget *parent)
     QQmlComponent *component = new QQmlComponent(engine());
     component->loadUrl(path);
     if (!component->isReady() ) {
-        qWarning() << ("%s", qPrintable(component->errorString()));
+        qCWarning(GRAPHTHEORY_GENERAL) << component->errorString();
         return;
     }
 
